No POD found for YN00.pm.
Time to read the source?
No POD found for YN00.pm.
Time to read the source?
To install YN00, copy and paste the appropriate command in to your terminal.
cpanm YN00
perl -MCPAN -e shell
install YN00
For more information on module installation, please visit the detailed CPAN module installation guide.
| Global | |
|---|---|
| s | Focus search bar |
| ? | Bring up this help dialog |
| GitHub | |
|---|---|
| g p | Go to pull requests |
| g i | Go to GitHub issues (only if GitHub is preferred repository) |
| POD | |
|---|---|
| g a | Go to author |
| g c | Go to changes |
| g i | Go to issues |
| g d | Go to dist |
| g r | Go to repository/SCM |
| g s | Go to source |
| g b | Go to file browse |
| Search terms | |
|---|---|
| module: (e.g. module:Plugin) | |
| distribution: (e.g. distribution:Dancer auth) | |
| author: (e.g. author:SONGMU Redis) | |
| version: (e.g. version:1.00) |